@@ -15,11 +15,11 @@ Toader::Page - This provides methods for a named page.
 
 =head1 VERSION
 
-Version 0.0.0
+Version 0.0.1
 
 =cut
 
-our $VERSION = '0.0.0';
+our $VERSION = '0.0.1';
 
 =head1 SYNOPSIS
 
@@ -396,7 +396,7 @@ sub bodySet{
 
 =head2 dirGet
 
-This gets Toader directory this entry is associated with.
+This gets L<Toader> directory this entry is associated with.
 
 This will only error if a permanent error is set.
 
@@ -419,9 +419,9 @@ sub dirGet{
 
 =head2 dirSet
 
-This sets Toader directory this entry is associated with.
+This sets L<Toader> directory this entry is associated with.
 
-One argument is taken and it is the Toader directory to set it to.
+One argument is taken and it is the L<Toader> directory to set it to.
 
     $foo->dirSet($toaderDirectory);
     if($foo->error){
@@ -834,7 +834,7 @@ sub subpartsExtract{
 =head2 subpartsGet
 
 This returns the results from the subparts
-methods from the internal Email::MIME object.
+methods from the internal L<Email::MIME> object.
 
     my @parts=$foo->subpartsGet;
     if ( $foo->error ){
@@ -1136,7 +1136,7 @@ sub renderUsing{
 
 =head2 toaderRenderable
 
-This method returns true and marks it as being Toader
+This method returns true and marks it as being L<Toader>
 renderable.
 
 =cut
@@ -1180,7 +1180,7 @@ No name specified.
 
 =head2 2
 
-Unable to create Email::MIME object.
+Unable to create L<Email::MIME> object.
 
 =head2 3
 
@@ -1200,7 +1200,7 @@ Unable to open the file.
 
 =head2 7
 
-Unable to create a Email::MIME object for one of the parts/files.
+Unable to create a L<Email::MIME> object for one of the parts/files.
 
 =head2 8
 
@@ -1208,11 +1208,11 @@ No body defined.
 
 =head2 9
 
-Not a Toader directory.
+Not a L<Toader> directory.
 
 =head2 10
 
-No longer appears to be a toader directory.
+No longer appears to be a L<Toader> directory.
 
 =head2 11
 
